@@ -13,4 +13,4 @@ This module contains the I/O methods for loading data into and saving data from
     load_arm_netcdf
 
 """
-from .arm_data import load_arm_netcdf
\ No newline at end of file
+from .arm_data import load_arm_netcdf, read_00_data
\ No newline at end of file
